<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * MAZ Loader Custom Field.
 *
 * @link       https://www.feataholic.com
 * @since      1.2.0 Free
 *
 * @package    MZLDR
 * @subpackage MZLDR/admin
 */

/**
 * MAZ Loader Custom Lottie Field.
 *
 * @package    MZLDR
 * @subpackage MZLDR/admin
 * @author     Your Name <email@example.com>
 */
class MZLDR_Lottie_Field extends MZLDR_Field {

	protected $text;

	public function __construct( $field_data = array() ) {
		if (!isset($field_data->id)) {
			return false;
		}

		$this->method = isset( $field_data->method ) ? $field_data->method : 'json';
		$this->json = isset( $field_data->json ) ? $field_data->json : '';
		$this->url = isset( $field_data->url ) ? $field_data->url : '';

		parent::__construct( $field_data );
	}

	protected function getFieldSettings() {
		$settings = array(
			'helper' => array(
				'type' => 'heading',
				'description' => 'Lottie Field ID: <em>&nbsp;' . $this->id . '&nbsp;&nbsp;</em>'
			),
			'method' => array(
				'field_id'    => $this->id,
				'type'        => 'dropdown',
				'id'          => 'mzldr_' . $this->method . '_field_type' . $this->id,
				'name'        => 'mzldr[data][' . $this->id . '][method]',
				'label'       => __( 'Data source', 'maz-loader' ),
				'value'       => isset( $this->method ) ? $this->method : 'json',
				'description' => __( 'Select whether to load data via JSON or URL.' , 'maz-loader' ),
				'values'      => array(
					'json' => __( 'JSON', 'maz-loader' ),
					'url' => __( 'URL', 'maz-loader' )
				)
			),
			'json' => array(
				'field_id'    => $this->id,
				'type'        => 'textarea',
				'id'          => 'mzldr_' . $this->type . '_field_data_' . $this->id,
				'name'        => 'mzldr[data][' . $this->id . '][json]',
				'label'       => __( 'JSON Data', 'maz-loader' ),
				'value'       => isset( $this->json ) && !empty($this->json) ? esc_attr( $this->json ) : '',
				'placeholder' => 'JSON data',
				'description' => __( 'Enter your JSON exported data here.', 'maz-loader' ),
				'rows'		  => 10,
				'class'		  => [ 'mzldr-conditionize' ],
				'extra_atts'  => array(
					'data-mzldr-cond-option' => 'mzldr[data][' . $this->id . '][method]',
					'data-mzldr-cond-value'  => 'json'
				),
			),
			'url' => array(
				'field_id'    => $this->id,
				'type'        => 'text',
				'id'          => 'mzldr_' . $this->type . '_field_url_' . $this->id,
				'name'        => 'mzldr[data][' . $this->id . '][url]',
				'label'       => __( 'JSON URL', 'maz-loader' ),
				'placeholder' => 'JSON data URL',
				'description' => __( 'Enter the URL that holds the JSON data.', 'maz-loader' ),
				'class'		  => [ 'mzldr-conditionize' ],
				'extra_atts'  => array(
					'data-mzldr-cond-option' => 'mzldr[data][' . $this->id . '][method]',
					'data-mzldr-cond-value'  => 'url'
				),
			)
		);

		return $settings;
	}

	public function getDefaultData( $id ) {
		$obj              = new stdClass();
		$obj->id          = $id;
		$obj->type        = 'lottie';
		$obj->method 	  = isset( $this->method ) ? $this->method : 'json';
		$obj->json 		  = isset( $this->json ) ? $this->json : '';
		$obj->url 		  = isset( $this->url ) ? $this->url : '';

		return $obj;
	}
}
